Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/monsterm4sk_simpletest.py
    :caption: examples/monsterm4sk_simpletest.py
    :linenos:

Rainbow Stars
-------------

Groovy color changing stars eyes.

.. literalinclude:: ../examples/monsterm4sk_rainbow_stars.py
    :caption: examples/monsterm4sk_rainbow_stars.py
    :linenos:

Pumpkin Shifting Eyes
---------------------

Triangle Jack-O-Lantern eyes that shift back and forth.

.. literalinclude:: ../examples/monsterm4sk_pumpkin_shifting_eyes.py
    :caption: examples/monsterm4sk_pumpkin_shifting_eyes.py
    :linenos:
